Error

Enum Error 

#[non_exhaustive]
pub enum Error {
Show 18 variants Store(String), NotFound(String), Version(u64), Id(u64), Timescale(u64), Priority { existing: u8, intended: u8, }, TimescaleMismatch { existing: u64, intended: u64, }, Empty, Sequence, Bounds { smallest: u64, largest: u64, }, Table, Overflow, Track, Path(String), Directory(String), Pagination, Conflict(String), Json(String),
}
Errors from encoding, decoding, or storing recording objects.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Store(String)

The backing object store failed.



NotFound(String)

No object exists at this key.



Version(u64)

The recording format version is not 1.



Id(u64)

A group ID, segment ID, or frame timestamp is outside 0 through 2^53 - 1.



Timescale(u64)

.info timescale is not in 1 through 2^53 - 1.



Priority

An existing .info has a different priority.

Fields

existing: u8
intended: u8


TimescaleMismatch

An existing .info has a different timescale.

Fields

existing: u64
intended: u64


Empty

The object has no groups.



Sequence

Group sequences are not strictly ascending.



Bounds

A group range is empty, reversed, or does not match an object’s table.

Fields

smallest: u64
largest: u64


Table

The binary table is truncated, overlapping, gapped, or out of range.



Overflow

Arithmetic overflowed while encoding or decoding.



Track

The track name is empty or its encoding is not canonical.



Path(String)

An object path is not a recording key.



Directory(String)

A backend returned a directory from the flat object listing API.



Pagination

A pagination continuation was passed to streaming list.



Conflict(String)

A create collided with different object bytes.



Json(String)

.info JSON is malformed.